﻿using Dynamicweb.Ecommerce.International;
using Dynamicweb.Ecommerce.LiveIntegration.Configuration;
using Dynamicweb.Extensibility.Notifications;

namespace Dynamicweb.Ecommerce.LiveIntegration.NotificationSubscribers
{
    /// <summary>
    /// Synchronizes the cart with the ERP when the carty loads.
    /// </summary>
    /// <seealso cref="NotificationSubscriberBase" />
    [Subscribe(Ecommerce.Notifications.Ecommerce.Cart.Loaded)]
    public class CartLoaded : NotificationSubscriberBase
    {
        /// <summary>
        /// Handles the notification.
        /// </summary>
        /// <param name="notification">The notification.</param>
        /// <param name="args">The args.</param>
        public override void OnNotify(string notification, NotificationArgs args)
        {
            var myArgs = args as Ecommerce.Notifications.Ecommerce.Cart.LoadedArgs;
            if (myArgs?.Cart == null || myArgs.Cart.OrderLines.Count <= 0 || !EnabledAndActive())
            {
                return;
            }
            if (Global.EnableCartCommunication(myArgs.Cart.Complete) &&
                !string.IsNullOrEmpty(Context.Current.Request["CurrencyCode"]) &&
                !string.Equals(myArgs.Cart.CurrencyCode, Context.Current.Request["CurrencyCode"], System.StringComparison.OrdinalIgnoreCase))
            {
                Currency currency = Services.Currencies.GetCurrency(Context.Current.Request["CurrencyCode"]);
                if (currency != null)
                {
                    myArgs.Cart.CurrencyCode = currency.Code;
                    Services.Orders.ClearCachedPrices(myArgs.Cart);
                    OrderHandler.UpdateOrder(myArgs.Cart, SubmitType.LiveOrderOrCart);
                }
            }
        }
    }
}